#
# -*- encoding: utf-8 -*-
#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from onf_website.root.interfaces import ISiteRootRoles, ISiteRootConfiguration, ISiteRoot, \
    ISiteRootToolsConfiguration, ISiteRootBackOfficeConfiguration
from pyams_portal.interfaces import IPortalContext
from pyams_skin.interfaces.configuration import IStaticConfiguration
from pyams_utils.interfaces.site import IConfigurationFactory, IBackOfficeConfigurationFactory
from zope.annotation.interfaces import IAnnotations

# import packages
from pyams_content.root import SiteRoot as SiteRootBase, \
                               SiteRootStaticConfiguration as SiteRootStaticConfigurationBase, \
                               SiteRootConfiguration as SiteRootConfigurationBase, \
                               SiteRootToolsConfiguration as SiteRootToolsConfigurationBase, \
                               SiteRootBackOfficeConfiguration as SiteRootBackOfficeConfigurationBase, \
                               SITEROOT_TOOLS_CONFIGURATION_KEY
from pyams_utils.adapter import adapter_config
from zope.interface import implementer, Interface


@adapter_config(context=(ISiteRoot, Interface, Interface), provides=IStaticConfiguration)
class SiteRootStaticConfiguration(SiteRootStaticConfigurationBase):
    """Site root static configuration"""

    application_package = 'onf_website'
    application_name = 'Atelier éditorial'


@implementer(ISiteRoot, ISiteRootRoles, IPortalContext)
class SiteRoot(SiteRootBase):
    """Main site root"""


@implementer(ISiteRootConfiguration)
class SiteRootConfiguration(SiteRootConfigurationBase):
    """Site root configuration"""


@adapter_config(context=ISiteRoot, provides=IConfigurationFactory)
def SiteRootConfigurationFactory(context):
    return SiteRootConfiguration


@implementer(ISiteRootBackOfficeConfiguration)
class SiteRootBackOfficeConfiguration(SiteRootBackOfficeConfigurationBase):
    """Site root back-office configuration"""


@adapter_config(context=ISiteRoot, provides=IBackOfficeConfigurationFactory)
def SiteRootConfigurationFactory(context):
    return SiteRootBackOfficeConfiguration


#
# Tools configuration
#

@implementer(ISiteRootToolsConfiguration)
class SiteRootToolsConfiguration(SiteRootToolsConfigurationBase):
    """Site root tools configuration"""

    tables_name = None
    country_table_name = None
    region_table_name = None
    department_table_name = None
    territory_table_name = None
    agency_table_name = None
    unit_table_name = None
    target_table_name = None


@adapter_config(context=ISiteRoot, provides=ISiteRootToolsConfiguration)
def site_root_tools_configuration_factory(context):
    """Site root tools configuration factory"""
    annotations = IAnnotations(context)
    config = annotations.get(SITEROOT_TOOLS_CONFIGURATION_KEY)
    if config is None:
        config = annotations[SITEROOT_TOOLS_CONFIGURATION_KEY] = SiteRootToolsConfiguration()
    return config
